Index: channels/chan_sip.c
===================================================================
--- channels/chan_sip.c	(revision 291906)
+++ channels/chan_sip.c	(working copy)
@@ -26341,8 +26341,18 @@
 				ast_log(LOG_ERROR, "Bad ACL entry in configuration line %d : %s\n", v->lineno, v->value);
 			}
 		}
+	} else if (peer->dnsmgr) {
+		ast_dnsmgr_refresh(peer->dnsmgr);
 	}
 
+	/* if the family type is not set for the addr, then the
+	 * next dns refresh will not be able to set the port type
+	 * correctly unless we specify the dnsmgr's default port. */
+	if (peer->dnsmgr && !peer->addr.ss.ss_family && port) {
+		ast_log(LOG_NOTICE, "HEY LEIF TELL ME IF YOU SEE THIS\n");
+		ast_dnsmgr_set_default_port(peer->dnsmgr, port);
+	}
+
 	if (port && !realtime && peer->host_dynamic) {
 		ast_sockaddr_set_port(&peer->defaddr, port);
 	} else if (port) {
Index: include/asterisk/dnsmgr.h
===================================================================
--- include/asterisk/dnsmgr.h	(revision 291906)
+++ include/asterisk/dnsmgr.h	(working copy)
@@ -64,6 +64,8 @@
  */
 void ast_dnsmgr_release(struct ast_dnsmgr_entry *entry);
 
+void ast_dnsmgr_set_default_port(struct ast_dnsmgr_entry *entry, int port);
+
 /*!
  * \brief Allocate and initialize a DNS manager entry
  *
Index: main/dnsmgr.c
===================================================================
--- main/dnsmgr.c	(revision 291906)
+++ main/dnsmgr.c	(working copy)
@@ -52,6 +52,8 @@
 struct ast_dnsmgr_entry {
 	/*! where we will store the resulting IP address and port number */
 	struct ast_sockaddr *result;
+	/*! optional default port if none is provided in result. */
+	int default_port;
 	/*! SRV record to lookup, if provided. Composed of service, protocol, and domain name: _Service._Proto.Name */
 	char *service;
 	/*! Set to 1 if the entry changes */
@@ -121,6 +123,11 @@
 	ast_free(entry);
 }
 
+void ast_dnsmgr_set_default_port(struct ast_dnsmgr_entry *entry, int port)
+{
+	entry->default_port = port;
+}
+
 int ast_dnsmgr_lookup(const char *name, struct ast_sockaddr *result, struct ast_dnsmgr_entry **dnsmgr, const char *service)
 {
 	if (ast_strlen_zero(name) || !result || !dnsmgr) {
@@ -162,7 +169,11 @@
 
 	if (!ast_get_ip_or_srv(&tmp, entry->name, entry->service)) {
 		if (!ast_sockaddr_port(&tmp)) {
-			ast_sockaddr_set_port(&tmp, ast_sockaddr_port(entry->result));
+			if (!ast_sockaddr_port(entry->result)) {
+				ast_sockaddr_set_port(&tmp, entry->default_port);
+			} else {
+				ast_sockaddr_set_port(&tmp, ast_sockaddr_port(entry->result));
+			}
 		}
 
 		if (ast_sockaddr_cmp(&tmp, entry->result)) {
